# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/common.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import latlng_pb2 as google_dot_type_dot_latlng__pb2
from google.type import money_pb2 as google_dot_type_dot_money__pb2
from google.type import postal_address_pb2 as google_dot_type_dot_postal__address__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/common.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\013CommonProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n.google/cloud/talent_v4beta1/proto/common.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x18google/type/latlng.proto\x1a\x17google/type/money.proto\x1a google/type/postal_address.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1cgoogle/api/annotations.proto"n\n\x0eTimestampRange\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"\xb7\x03\n\x08Location\x12I\n\rlocation_type\x18\x01 \x01(\x0e\x32\x32.google.cloud.talent.v4beta1.Location.LocationType\x12\x32\n\x0epostal_address\x18\x02 \x01(\x0b\x32\x1a.google.type.PostalAddress\x12$\n\x07lat_lng\x18\x03 \x01(\x0b\x32\x13.google.type.LatLng\x12\x14\n\x0cradius_miles\x18\x04 \x01(\x01"\xef\x01\n\x0cLocationType\x12\x1d\n\x19LOCATION_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x43OUNTRY\x10\x01\x12\x17\n\x13\x41\x44MINISTRATIVE_AREA\x10\x02\x12\x1b\n\x17SUB_ADMINISTRATIVE_AREA\x10\x03\x12\x0c\n\x08LOCALITY\x10\x04\x12\x0f\n\x0bPOSTAL_CODE\x10\x05\x12\x10\n\x0cSUB_LOCALITY\x10\x06\x12\x12\n\x0eSUB_LOCALITY_1\x10\x07\x12\x12\n\x0eSUB_LOCALITY_2\x10\x08\x12\x10\n\x0cNEIGHBORHOOD\x10\t\x12\x12\n\x0eSTREET_ADDRESS\x10\n"\x9f\x01\n\x0fRequestMetadata\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x19\n\x11\x61llow_missing_ids\x18\x04 \x01(\x08\x12<\n\x0b\x64\x65vice_info\x18\x05 \x01(\x0b\x32\'.google.cloud.talent.v4beta1.DeviceInfo"&\n\x10ResponseMetadata\x12\x12\n\nrequest_id\x18\x01 \x01(\t"\xcf\x01\n\nDeviceInfo\x12G\n\x0b\x64\x65vice_type\x18\x01 \x01(\x0e\x32\x32.google.cloud.talent.v4beta1.DeviceInfo.DeviceType\x12\n\n\x02id\x18\x02 \x01(\t"l\n\nDeviceType\x12\x1b\n\x17\x44\x45VICE_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03WEB\x10\x01\x12\x0e\n\nMOBILE_WEB\x10\x02\x12\x0b\n\x07\x41NDROID\x10\x03\x12\x07\n\x03IOS\x10\x04\x12\x07\n\x03\x42OT\x10\x05\x12\t\n\x05OTHER\x10\x06"Q\n\x0f\x43ustomAttribute\x12\x15\n\rstring_values\x18\x01 \x03(\t\x12\x13\n\x0blong_values\x18\x02 \x03(\x03\x12\x12\n\nfilterable\x18\x03 \x01(\x08"W\n\x12SpellingCorrection\x12\x11\n\tcorrected\x18\x01 \x01(\x08\x12\x16\n\x0e\x63orrected_text\x18\x02 \x01(\t\x12\x16\n\x0e\x63orrected_html\x18\x03 \x01(\t"\xa6\t\n\x10\x43ompensationInfo\x12P\n\x07\x65ntries\x18\x01 \x03(\x0b\x32?.google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry\x12p\n"annualized_base_compensation_range\x18\x02 \x01(\x0b\x32?.google.cloud.talent.v4beta1.CompensationInfo.CompensationRangeB\x03\xe0\x41\x03\x12q\n#annualized_total_compensation_range\x18\x03 \x01(\x0b\x32?.google.cloud.talent.v4beta1.CompensationInfo.CompensationRangeB\x03\xe0\x41\x03\x1a\x92\x03\n\x11\x43ompensationEntry\x12L\n\x04type\x18\x01 \x01(\x0e\x32>.google.cloud.talent.v4beta1.CompensationInfo.CompensationType\x12L\n\x04unit\x18\x02 \x01(\x0e\x32>.google.cloud.talent.v4beta1.CompensationInfo.CompensationUnit\x12$\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x12.google.type.MoneyH\x00\x12P\n\x05range\x18\x04 \x01(\x0b\x32?.google.cloud.talent.v4beta1.CompensationInfo.CompensationRangeH\x00\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12=\n\x17\x65xpected_units_per_year\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x15\n\x13\x63ompensation_amount\x1ao\n\x11\x43ompensationRange\x12,\n\x10max_compensation\x18\x02 \x01(\x0b\x32\x12.google.type.Money\x12,\n\x10min_compensation\x18\x01 \x01(\x0b\x32\x12.google.type.Money"\xb5\x01\n\x10\x43ompensationType\x12!\n\x1d\x43OMPENSATION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x42\x41SE\x10\x01\x12\t\n\x05\x42ONUS\x10\x02\x12\x11\n\rSIGNING_BONUS\x10\x03\x12\n\n\x06\x45QUITY\x10\x04\x12\x12\n\x0ePROFIT_SHARING\x10\x05\x12\x0f\n\x0b\x43OMMISSIONS\x10\x06\x12\x08\n\x04TIPS\x10\x07\x12\x1b\n\x17OTHER_COMPENSATION_TYPE\x10\x08"\x9c\x01\n\x10\x43ompensationUnit\x12!\n\x1d\x43OMPENSATION_UNIT_UNSPECIFIED\x10\x00\x12\n\n\x06HOURLY\x10\x01\x12\t\n\x05\x44\x41ILY\x10\x02\x12\n\n\x06WEEKLY\x10\x03\x12\x0b\n\x07MONTHLY\x10\x04\x12\n\n\x06YEARLY\x10\x05\x12\x0c\n\x08ONE_TIME\x10\x06\x12\x1b\n\x17OTHER_COMPENSATION_UNIT\x10\x07"\x9e\x01\n\rCertification\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\'\n\x0c\x61\x63quire_date\x18\x02 \x01(\x0b\x32\x11.google.type.Date\x12&\n\x0b\x65xpire_date\x18\x03 \x01(\x0b\x32\x11.google.type.Date\x12\x11\n\tauthority\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t"\xbd\x01\n\x05Skill\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12)\n\x0elast_used_date\x18\x02 \x01(\x0b\x32\x11.google.type.Date\x12\x41\n\x05level\x18\x03 \x01(\x0e\x32\x32.google.cloud.talent.v4beta1.SkillProficiencyLevel\x12\x0f\n\x07\x63ontext\x18\x04 \x01(\t\x12\x1f\n\x12skill_name_snippet\x18\x05 \x01(\tB\x03\xe0\x41\x03"|\n\tInterview\x12\x33\n\x06rating\x18\x06 \x01(\x0b\x32#.google.cloud.talent.v4beta1.Rating\x12:\n\x07outcome\x18\x07 \x01(\x0e\x32$.google.cloud.talent.v4beta1.OutcomeB\x03\xe0\x41\x02"E\n\x06Rating\x12\x0f\n\x07overall\x18\x01 \x01(\x01\x12\x0b\n\x03min\x18\x02 \x01(\x01\x12\x0b\n\x03max\x18\x03 \x01(\x01\x12\x10\n\x08interval\x18\x04 \x01(\x01"\xcc\x03\n\x16\x42\x61tchOperationMetadata\x12H\n\x05state\x18\x01 \x01(\x0e\x32\x39.google.cloud.talent.v4beta1.BatchOperationMetadata.State\x12\x19\n\x11state_description\x18\x02 \x01(\t\x12\x15\n\rsuccess_count\x18\x03 \x01(\x05\x12\x15\n\rfailure_count\x18\x04 \x01(\x05\x12\x13\n\x0btotal_count\x18\x05 \x01(\x05\x12/\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"z\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x10\n\x0cINITIALIZING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\r\n\tSUCCEEDED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0e\n\nCANCELLING\x10\x05\x12\r\n\tCANCELLED\x10\x06*y\n\x0b\x43ompanySize\x12\x1c\n\x18\x43OMPANY_SIZE_UNSPECIFIED\x10\x00\x12\x08\n\x04MINI\x10\x01\x12\t\n\x05SMALL\x10\x02\x12\x0b\n\x07SMEDIUM\x10\x03\x12\n\n\x06MEDIUM\x10\x04\x12\x07\n\x03\x42IG\x10\x05\x12\n\n\x06\x42IGGER\x10\x06\x12\t\n\x05GIANT\x10\x07*\xe2\x01\n\nJobBenefit\x12\x1b\n\x17JOB_BENEFIT_UNSPECIFIED\x10\x00\x12\x0e\n\nCHILD_CARE\x10\x01\x12\n\n\x06\x44\x45NTAL\x10\x02\x12\x14\n\x10\x44OMESTIC_PARTNER\x10\x03\x12\x12\n\x0e\x46LEXIBLE_HOURS\x10\x04\x12\x0b\n\x07MEDICAL\x10\x05\x12\x12\n\x0eLIFE_INSURANCE\x10\x06\x12\x12\n\x0ePARENTAL_LEAVE\x10\x07\x12\x13\n\x0fRETIREMENT_PLAN\x10\x08\x12\r\n\tSICK_DAYS\x10\t\x12\x0c\n\x08VACATION\x10\n\x12\n\n\x06VISION\x10\x0b*\x8e\x02\n\nDegreeType\x12\x1b\n\x17\x44\x45GREE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11PRIMARY_EDUCATION\x10\x01\x12\x1d\n\x19LOWER_SECONDARY_EDUCATION\x10\x02\x12\x1d\n\x19UPPER_SECONDARY_EDUCATION\x10\x03\x12\x1c\n\x18\x41\x44ULT_REMEDIAL_EDUCATION\x10\x04\x12\x1c\n\x18\x41SSOCIATES_OR_EQUIVALENT\x10\x05\x12\x1b\n\x17\x42\x41\x43HELORS_OR_EQUIVALENT\x10\x06\x12\x19\n\x15MASTERS_OR_EQUIVALENT\x10\x07\x12\x1a\n\x16\x44OCTORAL_OR_EQUIVALENT\x10\x08*\xdc\x01\n\x0e\x45mploymentType\x12\x1f\n\x1b\x45MPLOYMENT_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tFULL_TIME\x10\x01\x12\r\n\tPART_TIME\x10\x02\x12\x0e\n\nCONTRACTOR\x10\x03\x12\x14\n\x10\x43ONTRACT_TO_HIRE\x10\x04\x12\r\n\tTEMPORARY\x10\x05\x12\n\n\x06INTERN\x10\x06\x12\r\n\tVOLUNTEER\x10\x07\x12\x0c\n\x08PER_DIEM\x10\x08\x12\x12\n\x0e\x46LY_IN_FLY_OUT\x10\t\x12\x19\n\x15OTHER_EMPLOYMENT_TYPE\x10\n*q\n\x08JobLevel\x12\x19\n\x15JOB_LEVEL_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x45NTRY_LEVEL\x10\x01\x12\x0f\n\x0b\x45XPERIENCED\x10\x02\x12\x0b\n\x07MANAGER\x10\x03\x12\x0c\n\x08\x44IRECTOR\x10\x04\x12\r\n\tEXECUTIVE\x10\x05*\xba\x06\n\x0bJobCategory\x12\x1c\n\x18JOB_CATEGORY_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x41\x43\x43OUNTING_AND_FINANCE\x10\x01\x12\x1d\n\x19\x41\x44MINISTRATIVE_AND_OFFICE\x10\x02\x12\x1d\n\x19\x41\x44VERTISING_AND_MARKETING\x10\x03\x12\x0f\n\x0b\x41NIMAL_CARE\x10\x04\x12\x1a\n\x16\x41RT_FASHION_AND_DESIGN\x10\x05\x12\x17\n\x13\x42USINESS_OPERATIONS\x10\x06\x12\x1b\n\x17\x43LEANING_AND_FACILITIES\x10\x07\x12\x13\n\x0f\x43OMPUTER_AND_IT\x10\x08\x12\x10\n\x0c\x43ONSTRUCTION\x10\t\x12\x14\n\x10\x43USTOMER_SERVICE\x10\n\x12\r\n\tEDUCATION\x10\x0b\x12\x1c\n\x18\x45NTERTAINMENT_AND_TRAVEL\x10\x0c\x12\x18\n\x14\x46\x41RMING_AND_OUTDOORS\x10\r\x12\x0e\n\nHEALTHCARE\x10\x0e\x12\x13\n\x0fHUMAN_RESOURCES\x10\x0f\x12\'\n#INSTALLATION_MAINTENANCE_AND_REPAIR\x10\x10\x12\t\n\x05LEGAL\x10\x11\x12\x0e\n\nMANAGEMENT\x10\x12\x12\x1f\n\x1bMANUFACTURING_AND_WAREHOUSE\x10\x13\x12$\n MEDIA_COMMUNICATIONS_AND_WRITING\x10\x14\x12\x16\n\x12OIL_GAS_AND_MINING\x10\x15\x12\x1e\n\x1aPERSONAL_CARE_AND_SERVICES\x10\x16\x12\x17\n\x13PROTECTIVE_SERVICES\x10\x17\x12\x0f\n\x0bREAL_ESTATE\x10\x18\x12\x1e\n\x1aRESTAURANT_AND_HOSPITALITY\x10\x19\x12\x14\n\x10SALES_AND_RETAIL\x10\x1a\x12\x1b\n\x17SCIENCE_AND_ENGINEERING\x10\x1b\x12"\n\x1eSOCIAL_SERVICES_AND_NON_PROFIT\x10\x1c\x12!\n\x1dSPORTS_FITNESS_AND_RECREATION\x10\x1d\x12 \n\x1cTRANSPORTATION_AND_LOGISTICS\x10\x1e*e\n\rPostingRegion\x12\x1e\n\x1aPOSTING_REGION_UNSPECIFIED\x10\x00\x12\x17\n\x13\x41\x44MINISTRATIVE_AREA\x10\x01\x12\n\n\x06NATION\x10\x02\x12\x0f\n\x0bTELECOMMUTE\x10\x03*n\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x41\x43\x43OUNT_ONLY\x10\x01\x12\x16\n\x12SHARED_WITH_GOOGLE\x10\x02\x12\x16\n\x12SHARED_WITH_PUBLIC\x10\x03\x1a\x02\x18\x01*Z\n\x10\x43ontactInfoUsage\x12"\n\x1e\x43ONTACT_INFO_USAGE_UNSPECIFIED\x10\x00\x12\x0c\n\x08PERSONAL\x10\x01\x12\x08\n\x04WORK\x10\x02\x12\n\n\x06SCHOOL\x10\x03*q\n\x10HtmlSanitization\x12!\n\x1dHTML_SANITIZATION_UNSPECIFIED\x10\x00\x12\x1e\n\x1aHTML_SANITIZATION_DISABLED\x10\x01\x12\x1a\n\x16SIMPLE_FORMATTING_ONLY\x10\x02*c\n\rCommuteMethod\x12\x1e\n\x1a\x43OMMUTE_METHOD_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x44RIVING\x10\x01\x12\x0b\n\x07TRANSIT\x10\x02\x12\x0b\n\x07WALKING\x10\x03\x12\x0b\n\x07\x43YCLING\x10\x04*\xa2\x01\n\x15SkillProficiencyLevel\x12\'\n#SKILL_PROFICIENCY_LEVEL_UNSPECIFIED\x10\x00\x12\r\n\tUNSKILLED\x10\x06\x12\x19\n\x15\x46UNDAMENTAL_AWARENESS\x10\x01\x12\n\n\x06NOVICE\x10\x02\x12\x10\n\x0cINTERMEDIATE\x10\x03\x12\x0c\n\x08\x41\x44VANCED\x10\x04\x12\n\n\x06\x45XPERT\x10\x05*f\n\x07Outcome\x12\x17\n\x13OUTCOME_UNSPECIFIED\x10\x00\x12\x0c\n\x08POSITIVE\x10\x01\x12\x0b\n\x07NEUTRAL\x10\x02\x12\x0c\n\x08NEGATIVE\x10\x03\x12\x19\n\x15OUTCOME_NOT_AVAILABLE\x10\x04*\x97\x01\n\x16\x41vailabilitySignalType\x12(\n$AVAILABILITY_SIGNAL_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fJOB_APPLICATION\x10\x01\x12\x11\n\rRESUME_UPDATE\x10\x02\x12\x14\n\x10\x43\x41NDIDATE_UPDATE\x10\x03\x12\x15\n\x11\x43LIENT_SUBMISSION\x10\x04\x42y\n\x1f\x63om.google.cloud.talent.v4beta1B\x0b\x43ommonProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,
        google_dot_type_dot_date__pb2.DESCRIPTOR,
        google_dot_type_dot_latlng__pb2.DESCRIPTOR,
        google_dot_type_dot_money__pb2.DESCRIPTOR,
        google_dot_type_dot_postal__address__pb2.DESCRIPTOR,
        google_dot_type_dot_timeofday__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)

_COMPANYSIZE = _descriptor.EnumDescriptor(
    name="CompanySize",
    full_name="google.cloud.talent.v4beta1.CompanySize",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="COMPANY_SIZE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="MINI", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SMALL", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SMEDIUM", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MEDIUM", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="BIG", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="BIGGER", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="GIANT", index=7, number=7, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3689,
    serialized_end=3810,
)
_sym_db.RegisterEnumDescriptor(_COMPANYSIZE)

CompanySize = enum_type_wrapper.EnumTypeWrapper(_COMPANYSIZE)
_JOBBENEFIT = _descriptor.EnumDescriptor(
    name="JobBenefit",
    full_name="google.cloud.talent.v4beta1.JobBenefit",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="JOB_BENEFIT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="CHILD_CARE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DENTAL", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DOMESTIC_PARTNER",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="FLEXIBLE_HOURS", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MEDICAL", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="LIFE_INSURANCE", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PARENTAL_LEAVE", index=7, number=7, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="RETIREMENT_PLAN",
            index=8,
            number=8,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="SICK_DAYS", index=9, number=9, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="VACATION", index=10, number=10, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="VISION", index=11, number=11, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3813,
    serialized_end=4039,
)
_sym_db.RegisterEnumDescriptor(_JOBBENEFIT)

JobBenefit = enum_type_wrapper.EnumTypeWrapper(_JOBBENEFIT)
_DEGREETYPE = _descriptor.EnumDescriptor(
    name="DegreeType",
    full_name="google.cloud.talent.v4beta1.DegreeType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="DEGREE_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="PRIMARY_EDUCATION",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="LOWER_SECONDARY_EDUCATION",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="UPPER_SECONDARY_EDUCATION",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ADULT_REMEDIAL_EDUCATION",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ASSOCIATES_OR_EQUIVALENT",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="BACHELORS_OR_EQUIVALENT",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="MASTERS_OR_EQUIVALENT",
            index=7,
            number=7,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="DOCTORAL_OR_EQUIVALENT",
            index=8,
            number=8,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=4042,
    serialized_end=4312,
)
_sym_db.RegisterEnumDescriptor(_DEGREETYPE)

DegreeType = enum_type_wrapper.EnumTypeWrapper(_DEGREETYPE)
_EMPLOYMENTTYPE = _descriptor.EnumDescriptor(
    name="EmploymentType",
    full_name="google.cloud.talent.v4beta1.EmploymentType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="EMPLOYMENT_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="FULL_TIME", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PART_TIME", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CONTRACTOR", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CONTRACT_TO_HIRE",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="TEMPORARY", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="INTERN", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="VOLUNTEER", index=7, number=7, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PER_DIEM", index=8, number=8, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="FLY_IN_FLY_OUT", index=9, number=9, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="OTHER_EMPLOYMENT_TYPE",
            index=10,
            number=10,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=4315,
    serialized_end=4535,
)
_sym_db.RegisterEnumDescriptor(_EMPLOYMENTTYPE)

EmploymentType = enum_type_wrapper.EnumTypeWrapper(_EMPLOYMENTTYPE)
_JOBLEVEL = _descriptor.EnumDescriptor(
    name="JobLevel",
    full_name="google.cloud.talent.v4beta1.JobLevel",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="JOB_LEVEL_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ENTRY_LEVEL", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="EXPERIENCED", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MANAGER", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DIRECTOR", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="EXECUTIVE", index=5, number=5, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=4537,
    serialized_end=4650,
)
_sym_db.RegisterEnumDescriptor(_JOBLEVEL)

JobLevel = enum_type_wrapper.EnumTypeWrapper(_JOBLEVEL)
_JOBCATEGORY = _descriptor.EnumDescriptor(
    name="JobCategory",
    full_name="google.cloud.talent.v4beta1.JobCategory",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="JOB_CATEGORY_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ACCOUNTING_AND_FINANCE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ADMINISTRATIVE_AND_OFFICE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ADVERTISING_AND_MARKETING",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ANIMAL_CARE", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ART_FASHION_AND_DESIGN",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="BUSINESS_OPERATIONS",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="CLEANING_AND_FACILITIES",
            index=7,
            number=7,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="COMPUTER_AND_IT",
            index=8,
            number=8,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="CONSTRUCTION", index=9, number=9, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CUSTOMER_SERVICE",
            index=10,
            number=10,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="EDUCATION", index=11, number=11, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ENTERTAINMENT_AND_TRAVEL",
            index=12,
            number=12,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="FARMING_AND_OUTDOORS",
            index=13,
            number=13,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="HEALTHCARE", index=14, number=14, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="HUMAN_RESOURCES",
            index=15,
            number=15,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="INSTALLATION_MAINTENANCE_AND_REPAIR",
            index=16,
            number=16,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="LEGAL", index=17, number=17, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MANAGEMENT", index=18, number=18, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MANUFACTURING_AND_WAREHOUSE",
            index=19,
            number=19,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="MEDIA_COMMUNICATIONS_AND_WRITING",
            index=20,
            number=20,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="OIL_GAS_AND_MINING",
            index=21,
            number=21,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="PERSONAL_CARE_AND_SERVICES",
            index=22,
            number=22,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="PROTECTIVE_SERVICES",
            index=23,
            number=23,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="REAL_ESTATE", index=24, number=24, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="RESTAURANT_AND_HOSPITALITY",
            index=25,
            number=25,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="SALES_AND_RETAIL",
            index=26,
            number=26,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="SCIENCE_AND_ENGINEERING",
            index=27,
            number=27,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="SOCIAL_SERVICES_AND_NON_PROFIT",
            index=28,
            number=28,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="SPORTS_FITNESS_AND_RECREATION",
            index=29,
            number=29,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="TRANSPORTATION_AND_LOGISTICS",
            index=30,
            number=30,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=4653,
    serialized_end=5479,
)
_sym_db.RegisterEnumDescriptor(_JOBCATEGORY)

JobCategory = enum_type_wrapper.EnumTypeWrapper(_JOBCATEGORY)
_POSTINGREGION = _descriptor.EnumDescriptor(
    name="PostingRegion",
    full_name="google.cloud.talent.v4beta1.PostingRegion",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="POSTING_REGION_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ADMINISTRATIVE_AREA",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="NATION", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TELECOMMUTE", index=3, number=3, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=5481,
    serialized_end=5582,
)
_sym_db.RegisterEnumDescriptor(_POSTINGREGION)

PostingRegion = enum_type_wrapper.EnumTypeWrapper(_POSTINGREGION)
_VISIBILITY = _descriptor.EnumDescriptor(
    name="Visibility",
    full_name="google.cloud.talent.v4beta1.Visibility",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="VISIBILITY_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ACCOUNT_ONLY", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SHARED_WITH_GOOGLE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="SHARED_WITH_PUBLIC",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=_b("\030\001"),
    serialized_start=5584,
    serialized_end=5694,
)
_sym_db.RegisterEnumDescriptor(_VISIBILITY)

Visibility = enum_type_wrapper.EnumTypeWrapper(_VISIBILITY)
_CONTACTINFOUSAGE = _descriptor.EnumDescriptor(
    name="ContactInfoUsage",
    full_name="google.cloud.talent.v4beta1.ContactInfoUsage",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CONTACT_INFO_USAGE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="PERSONAL", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="WORK", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SCHOOL", index=3, number=3, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=5696,
    serialized_end=5786,
)
_sym_db.RegisterEnumDescriptor(_CONTACTINFOUSAGE)

ContactInfoUsage = enum_type_wrapper.EnumTypeWrapper(_CONTACTINFOUSAGE)
_HTMLSANITIZATION = _descriptor.EnumDescriptor(
    name="HtmlSanitization",
    full_name="google.cloud.talent.v4beta1.HtmlSanitization",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="HTML_SANITIZATION_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="HTML_SANITIZATION_DISABLED",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="SIMPLE_FORMATTING_ONLY",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=5788,
    serialized_end=5901,
)
_sym_db.RegisterEnumDescriptor(_HTMLSANITIZATION)

HtmlSanitization = enum_type_wrapper.EnumTypeWrapper(_HTMLSANITIZATION)
_COMMUTEMETHOD = _descriptor.EnumDescriptor(
    name="CommuteMethod",
    full_name="google.cloud.talent.v4beta1.CommuteMethod",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="COMMUTE_METHOD_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="DRIVING", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TRANSIT", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="WALKING", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CYCLING", index=4, number=4, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=5903,
    serialized_end=6002,
)
_sym_db.RegisterEnumDescriptor(_COMMUTEMETHOD)

CommuteMethod = enum_type_wrapper.EnumTypeWrapper(_COMMUTEMETHOD)
_SKILLPROFICIENCYLEVEL = _descriptor.EnumDescriptor(
    name="SkillProficiencyLevel",
    full_name="google.cloud.talent.v4beta1.SkillProficiencyLevel",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SKILL_PROFICIENCY_LEVEL_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="UNSKILLED", index=1, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="FUNDAMENTAL_AWARENESS",
            index=2,
            number=1,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="NOVICE", index=3, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="INTERMEDIATE", index=4, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ADVANCED", index=5, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="EXPERT", index=6, number=5, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=6005,
    serialized_end=6167,
)
_sym_db.RegisterEnumDescriptor(_SKILLPROFICIENCYLEVEL)

SkillProficiencyLevel = enum_type_wrapper.EnumTypeWrapper(_SKILLPROFICIENCYLEVEL)
_OUTCOME = _descriptor.EnumDescriptor(
    name="Outcome",
    full_name="google.cloud.talent.v4beta1.Outcome",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="OUTCOME_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="POSITIVE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="NEUTRAL", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="NEGATIVE", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="OUTCOME_NOT_AVAILABLE",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=6169,
    serialized_end=6271,
)
_sym_db.RegisterEnumDescriptor(_OUTCOME)

Outcome = enum_type_wrapper.EnumTypeWrapper(_OUTCOME)
_AVAILABILITYSIGNALTYPE = _descriptor.EnumDescriptor(
    name="AvailabilitySignalType",
    full_name="google.cloud.talent.v4beta1.AvailabilitySignalType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="AVAILABILITY_SIGNAL_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="JOB_APPLICATION",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="RESUME_UPDATE", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CANDIDATE_UPDATE",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="CLIENT_SUBMISSION",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=6274,
    serialized_end=6425,
)
_sym_db.RegisterEnumDescriptor(_AVAILABILITYSIGNALTYPE)

AvailabilitySignalType = enum_type_wrapper.EnumTypeWrapper(_AVAILABILITYSIGNALTYPE)
COMPANY_SIZE_UNSPECIFIED = 0
MINI = 1
SMALL = 2
SMEDIUM = 3
MEDIUM = 4
BIG = 5
BIGGER = 6
GIANT = 7
JOB_BENEFIT_UNSPECIFIED = 0
CHILD_CARE = 1
DENTAL = 2
DOMESTIC_PARTNER = 3
FLEXIBLE_HOURS = 4
MEDICAL = 5
LIFE_INSURANCE = 6
PARENTAL_LEAVE = 7
RETIREMENT_PLAN = 8
SICK_DAYS = 9
VACATION = 10
VISION = 11
DEGREE_TYPE_UNSPECIFIED = 0
PRIMARY_EDUCATION = 1
LOWER_SECONDARY_EDUCATION = 2
UPPER_SECONDARY_EDUCATION = 3
ADULT_REMEDIAL_EDUCATION = 4
ASSOCIATES_OR_EQUIVALENT = 5
BACHELORS_OR_EQUIVALENT = 6
MASTERS_OR_EQUIVALENT = 7
DOCTORAL_OR_EQUIVALENT = 8
EMPLOYMENT_TYPE_UNSPECIFIED = 0
FULL_TIME = 1
PART_TIME = 2
CONTRACTOR = 3
CONTRACT_TO_HIRE = 4
TEMPORARY = 5
INTERN = 6
VOLUNTEER = 7
PER_DIEM = 8
FLY_IN_FLY_OUT = 9
OTHER_EMPLOYMENT_TYPE = 10
JOB_LEVEL_UNSPECIFIED = 0
ENTRY_LEVEL = 1
EXPERIENCED = 2
MANAGER = 3
DIRECTOR = 4
EXECUTIVE = 5
JOB_CATEGORY_UNSPECIFIED = 0
ACCOUNTING_AND_FINANCE = 1
ADMINISTRATIVE_AND_OFFICE = 2
ADVERTISING_AND_MARKETING = 3
ANIMAL_CARE = 4
ART_FASHION_AND_DESIGN = 5
BUSINESS_OPERATIONS = 6
CLEANING_AND_FACILITIES = 7
COMPUTER_AND_IT = 8
CONSTRUCTION = 9
CUSTOMER_SERVICE = 10
EDUCATION = 11
ENTERTAINMENT_AND_TRAVEL = 12
FARMING_AND_OUTDOORS = 13
HEALTHCARE = 14
HUMAN_RESOURCES = 15
INSTALLATION_MAINTENANCE_AND_REPAIR = 16
LEGAL = 17
MANAGEMENT = 18
MANUFACTURING_AND_WAREHOUSE = 19
MEDIA_COMMUNICATIONS_AND_WRITING = 20
OIL_GAS_AND_MINING = 21
PERSONAL_CARE_AND_SERVICES = 22
PROTECTIVE_SERVICES = 23
REAL_ESTATE = 24
RESTAURANT_AND_HOSPITALITY = 25
SALES_AND_RETAIL = 26
SCIENCE_AND_ENGINEERING = 27
SOCIAL_SERVICES_AND_NON_PROFIT = 28
SPORTS_FITNESS_AND_RECREATION = 29
TRANSPORTATION_AND_LOGISTICS = 30
POSTING_REGION_UNSPECIFIED = 0
ADMINISTRATIVE_AREA = 1
NATION = 2
TELECOMMUTE = 3
VISIBILITY_UNSPECIFIED = 0
ACCOUNT_ONLY = 1
SHARED_WITH_GOOGLE = 2
SHARED_WITH_PUBLIC = 3
CONTACT_INFO_USAGE_UNSPECIFIED = 0
PERSONAL = 1
WORK = 2
SCHOOL = 3
HTML_SANITIZATION_UNSPECIFIED = 0
HTML_SANITIZATION_DISABLED = 1
SIMPLE_FORMATTING_ONLY = 2
COMMUTE_METHOD_UNSPECIFIED = 0
DRIVING = 1
TRANSIT = 2
WALKING = 3
CYCLING = 4
SKILL_PROFICIENCY_LEVEL_UNSPECIFIED = 0
UNSKILLED = 6
FUNDAMENTAL_AWARENESS = 1
NOVICE = 2
INTERMEDIATE = 3
ADVANCED = 4
EXPERT = 5
OUTCOME_UNSPECIFIED = 0
POSITIVE = 1
NEUTRAL = 2
NEGATIVE = 3
OUTCOME_NOT_AVAILABLE = 4
AVAILABILITY_SIGNAL_TYPE_UNSPECIFIED = 0
JOB_APPLICATION = 1
RESUME_UPDATE = 2
CANDIDATE_UPDATE = 3
CLIENT_SUBMISSION = 4


_LOCATION_LOCATIONTYPE = _descriptor.EnumDescriptor(
    name="LocationType",
    full_name="google.cloud.talent.v4beta1.Location.LocationType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="LOCATION_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="COUNTRY", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ADMINISTRATIVE_AREA",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="SUB_ADMINISTRATIVE_AREA",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="LOCALITY", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="POSTAL_CODE", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SUB_LOCALITY", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SUB_LOCALITY_1", index=7, number=7, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SUB_LOCALITY_2", index=8, number=8, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="NEIGHBORHOOD", index=9, number=9, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="STREET_ADDRESS",
            index=10,
            number=10,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=658,
    serialized_end=897,
)
_sym_db.RegisterEnumDescriptor(_LOCATION_LOCATIONTYPE)

_DEVICEINFO_DEVICETYPE = _descriptor.EnumDescriptor(
    name="DeviceType",
    full_name="google.cloud.talent.v4beta1.DeviceInfo.DeviceType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="DEVICE_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="WEB", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MOBILE_WEB", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ANDROID", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="IOS", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="BOT", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="OTHER", index=6, number=6, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1201,
    serialized_end=1309,
)
_sym_db.RegisterEnumDescriptor(_DEVICEINFO_DEVICETYPE)

_COMPENSATIONINFO_COMPENSATIONTYPE = _descriptor.EnumDescriptor(
    name="CompensationType",
    full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="COMPENSATION_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="BASE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="BONUS", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SIGNING_BONUS", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="EQUITY", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PROFIT_SHARING", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="COMMISSIONS", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TIPS", index=7, number=7, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="OTHER_COMPENSATION_TYPE",
            index=8,
            number=8,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2334,
    serialized_end=2515,
)
_sym_db.RegisterEnumDescriptor(_COMPENSATIONINFO_COMPENSATIONTYPE)

_COMPENSATIONINFO_COMPENSATIONUNIT = _descriptor.EnumDescriptor(
    name="CompensationUnit",
    full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationUnit",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="COMPENSATION_UNIT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="HOURLY", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DAILY", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="WEEKLY", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MONTHLY", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="YEARLY", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ONE_TIME", index=6, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="OTHER_COMPENSATION_UNIT",
            index=7,
            number=7,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2518,
    serialized_end=2674,
)
_sym_db.RegisterEnumDescriptor(_COMPENSATIONINFO_COMPENSATIONUNIT)

_BATCHOPERATIONMETADATA_STATE = _descriptor.EnumDescriptor(
    name="State",
    full_name="google.cloud.talent.v4beta1.BatchOperationMetadata.State",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="STATE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="INITIALIZING", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="PROCESSING", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SUCCEEDED", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="FAILED", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CANCELLING", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CANCELLED", index=6, number=6, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3565,
    serialized_end=3687,
)
_sym_db.RegisterEnumDescriptor(_BATCHOPERATIONMETADATA_STATE)


_TIMESTAMPRANGE = _descriptor.Descriptor(
    name="TimestampRange",
    full_name="google.cloud.talent.v4beta1.TimestampRange",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="start_time",
            full_name="google.cloud.talent.v4beta1.TimestampRange.start_time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end_time",
            full_name="google.cloud.talent.v4beta1.TimestampRange.end_time",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=345,
    serialized_end=455,
)


_LOCATION = _descriptor.Descriptor(
    name="Location",
    full_name="google.cloud.talent.v4beta1.Location",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="location_type",
            full_name="google.cloud.talent.v4beta1.Location.location_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="postal_address",
            full_name="google.cloud.talent.v4beta1.Location.postal_address",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="lat_lng",
            full_name="google.cloud.talent.v4beta1.Location.lat_lng",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="radius_miles",
            full_name="google.cloud.talent.v4beta1.Location.radius_miles",
            index=3,
            number=4,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_LOCATION_LOCATIONTYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=458,
    serialized_end=897,
)


_REQUESTMETADATA = _descriptor.Descriptor(
    name="RequestMetadata",
    full_name="google.cloud.talent.v4beta1.RequestMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="domain",
            full_name="google.cloud.talent.v4beta1.RequestMetadata.domain",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="session_id",
            full_name="google.cloud.talent.v4beta1.RequestMetadata.session_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="user_id",
            full_name="google.cloud.talent.v4beta1.RequestMetadata.user_id",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="allow_missing_ids",
            full_name="google.cloud.talent.v4beta1.RequestMetadata.allow_missing_ids",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="device_info",
            full_name="google.cloud.talent.v4beta1.RequestMetadata.device_info",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=900,
    serialized_end=1059,
)


_RESPONSEMETADATA = _descriptor.Descriptor(
    name="ResponseMetadata",
    full_name="google.cloud.talent.v4beta1.ResponseMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="request_id",
            full_name="google.cloud.talent.v4beta1.ResponseMetadata.request_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1061,
    serialized_end=1099,
)


_DEVICEINFO = _descriptor.Descriptor(
    name="DeviceInfo",
    full_name="google.cloud.talent.v4beta1.DeviceInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="device_type",
            full_name="google.cloud.talent.v4beta1.DeviceInfo.device_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="id",
            full_name="google.cloud.talent.v4beta1.DeviceInfo.id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_DEVICEINFO_DEVICETYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1102,
    serialized_end=1309,
)


_CUSTOMATTRIBUTE = _descriptor.Descriptor(
    name="CustomAttribute",
    full_name="google.cloud.talent.v4beta1.CustomAttribute",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="string_values",
            full_name="google.cloud.talent.v4beta1.CustomAttribute.string_values",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="long_values",
            full_name="google.cloud.talent.v4beta1.CustomAttribute.long_values",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filterable",
            full_name="google.cloud.talent.v4beta1.CustomAttribute.filterable",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1311,
    serialized_end=1392,
)


_SPELLINGCORRECTION = _descriptor.Descriptor(
    name="SpellingCorrection",
    full_name="google.cloud.talent.v4beta1.SpellingCorrection",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="corrected",
            full_name="google.cloud.talent.v4beta1.SpellingCorrection.corrected",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="corrected_text",
            full_name="google.cloud.talent.v4beta1.SpellingCorrection.corrected_text",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="corrected_html",
            full_name="google.cloud.talent.v4beta1.SpellingCorrection.corrected_html",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1394,
    serialized_end=1481,
)


_COMPENSATIONINFO_COMPENSATIONENTRY = _descriptor.Descriptor(
    name="CompensationEntry",
    full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="unit",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.unit",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="amount",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.amount",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="range",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.range",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.description",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="expected_units_per_year",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.expected_units_per_year",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="compensation_amount",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.compensation_amount",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1816,
    serialized_end=2218,
)

_COMPENSATIONINFO_COMPENSATIONRANGE = _descriptor.Descriptor(
    name="CompensationRange",
    full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationRange",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="max_compensation",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationRange.max_compensation",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="min_compensation",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.CompensationRange.min_compensation",
            index=1,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2220,
    serialized_end=2331,
)

_COMPENSATIONINFO = _descriptor.Descriptor(
    name="CompensationInfo",
    full_name="google.cloud.talent.v4beta1.CompensationInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="entries",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.entries",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="annualized_base_compensation_range",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.annualized_base_compensation_range",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="annualized_total_compensation_range",
            full_name="google.cloud.talent.v4beta1.CompensationInfo.annualized_total_compensation_range",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[
        _COMPENSATIONINFO_COMPENSATIONENTRY,
        _COMPENSATIONINFO_COMPENSATIONRANGE,
    ],
    enum_types=[_COMPENSATIONINFO_COMPENSATIONTYPE, _COMPENSATIONINFO_COMPENSATIONUNIT],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1484,
    serialized_end=2674,
)


_CERTIFICATION = _descriptor.Descriptor(
    name="Certification",
    full_name="google.cloud.talent.v4beta1.Certification",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.talent.v4beta1.Certification.display_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="acquire_date",
            full_name="google.cloud.talent.v4beta1.Certification.acquire_date",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="expire_date",
            full_name="google.cloud.talent.v4beta1.Certification.expire_date",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="authority",
            full_name="google.cloud.talent.v4beta1.Certification.authority",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.talent.v4beta1.Certification.description",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2677,
    serialized_end=2835,
)


_SKILL = _descriptor.Descriptor(
    name="Skill",
    full_name="google.cloud.talent.v4beta1.Skill",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.talent.v4beta1.Skill.display_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="last_used_date",
            full_name="google.cloud.talent.v4beta1.Skill.last_used_date",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="level",
            full_name="google.cloud.talent.v4beta1.Skill.level",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="google.cloud.talent.v4beta1.Skill.context",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="skill_name_snippet",
            full_name="google.cloud.talent.v4beta1.Skill.skill_name_snippet",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\003"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2838,
    serialized_end=3027,
)


_INTERVIEW = _descriptor.Descriptor(
    name="Interview",
    full_name="google.cloud.talent.v4beta1.Interview",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="rating",
            full_name="google.cloud.talent.v4beta1.Interview.rating",
            index=0,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="outcome",
            full_name="google.cloud.talent.v4beta1.Interview.outcome",
            index=1,
            number=7,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3029,
    serialized_end=3153,
)


_RATING = _descriptor.Descriptor(
    name="Rating",
    full_name="google.cloud.talent.v4beta1.Rating",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="overall",
            full_name="google.cloud.talent.v4beta1.Rating.overall",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="min",
            full_name="google.cloud.talent.v4beta1.Rating.min",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="max",
            full_name="google.cloud.talent.v4beta1.Rating.max",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="interval",
            full_name="google.cloud.talent.v4beta1.Rating.interval",
            index=3,
            number=4,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3155,
    serialized_end=3224,
)


_BATCHOPERATIONMETADATA = _descriptor.Descriptor(
    name="BatchOperationMetadata",
    full_name="google.cloud.talent.v4beta1.BatchOperationMetadata",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="state",
            full_name="google.cloud.talent.v4beta1.BatchOperationMetadata.state",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="state_description",
            full_name="google.cloud.talent.v4beta1.BatchOperationMetadata.state_description",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="success_count",
            full_name="google.cloud.talent.v4beta1.BatchOperationMetadata.success_count",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="failure_count",
            full_name="google.cloud.talent.v4beta1.BatchOperationMetadata.failure_count",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="total_count",
            full_name="google.cloud.talent.v4beta1.BatchOperationMetadata.total_count",
            index=4,
            number=5,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="google.cloud.talent.v4beta1.BatchOperationMetadata.create_time",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="google.cloud.talent.v4beta1.BatchOperationMetadata.update_time",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end_time",
            full_name="google.cloud.talent.v4beta1.BatchOperationMetadata.end_time",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_BATCHOPERATIONMETADATA_STATE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3227,
    serialized_end=3687,
)

_TIMESTAMPRANGE.fields_by_name[
    "start_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMESTAMPRANGE.fields_by_name[
    "end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOCATION.fields_by_name["location_type"].enum_type = _LOCATION_LOCATIONTYPE
_LOCATION.fields_by_name[
    "postal_address"
].message_type = google_dot_type_dot_postal__address__pb2._POSTALADDRESS
_LOCATION.fields_by_name[
    "lat_lng"
].message_type = google_dot_type_dot_latlng__pb2._LATLNG
_LOCATION_LOCATIONTYPE.containing_type = _LOCATION
_REQUESTMETADATA.fields_by_name["device_info"].message_type = _DEVICEINFO
_DEVICEINFO.fields_by_name["device_type"].enum_type = _DEVICEINFO_DEVICETYPE
_DEVICEINFO_DEVICETYPE.containing_type = _DEVICEINFO
_COMPENSATIONINFO_COMPENSATIONENTRY.fields_by_name[
    "type"
].enum_type = _COMPENSATIONINFO_COMPENSATIONTYPE
_COMPENSATIONINFO_COMPENSATIONENTRY.fields_by_name[
    "unit"
].enum_type = _COMPENSATIONINFO_COMPENSATIONUNIT
_COMPENSATIONINFO_COMPENSATIONENTRY.fields_by_name[
    "amount"
].message_type = google_dot_type_dot_money__pb2._MONEY
_COMPENSATIONINFO_COMPENSATIONENTRY.fields_by_name[
    "range"
].message_type = _COMPENSATIONINFO_COMPENSATIONRANGE
_COMPENSATIONINFO_COMPENSATIONENTRY.fields_by_name[
    "expected_units_per_year"
].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_COMPENSATIONINFO_COMPENSATIONENTRY.containing_type = _COMPENSATIONINFO
_COMPENSATIONINFO_COMPENSATIONENTRY.oneofs_by_name["compensation_amount"].fields.append(
    _COMPENSATIONINFO_COMPENSATIONENTRY.fields_by_name["amount"]
)
_COMPENSATIONINFO_COMPENSATIONENTRY.fields_by_name[
    "amount"
].containing_oneof = _COMPENSATIONINFO_COMPENSATIONENTRY.oneofs_by_name[
    "compensation_amount"
]
_COMPENSATIONINFO_COMPENSATIONENTRY.oneofs_by_name["compensation_amount"].fields.append(
    _COMPENSATIONINFO_COMPENSATIONENTRY.fields_by_name["range"]
)
_COMPENSATIONINFO_COMPENSATIONENTRY.fields_by_name[
    "range"
].containing_oneof = _COMPENSATIONINFO_COMPENSATIONENTRY.oneofs_by_name[
    "compensation_amount"
]
_COMPENSATIONINFO_COMPENSATIONRANGE.fields_by_name[
    "max_compensation"
].message_type = google_dot_type_dot_money__pb2._MONEY
_COMPENSATIONINFO_COMPENSATIONRANGE.fields_by_name[
    "min_compensation"
].message_type = google_dot_type_dot_money__pb2._MONEY
_COMPENSATIONINFO_COMPENSATIONRANGE.containing_type = _COMPENSATIONINFO
_COMPENSATIONINFO.fields_by_name[
    "entries"
].message_type = _COMPENSATIONINFO_COMPENSATIONENTRY
_COMPENSATIONINFO.fields_by_name[
    "annualized_base_compensation_range"
].message_type = _COMPENSATIONINFO_COMPENSATIONRANGE
_COMPENSATIONINFO.fields_by_name[
    "annualized_total_compensation_range"
].message_type = _COMPENSATIONINFO_COMPENSATIONRANGE
_COMPENSATIONINFO_COMPENSATIONTYPE.containing_type = _COMPENSATIONINFO
_COMPENSATIONINFO_COMPENSATIONUNIT.containing_type = _COMPENSATIONINFO
_CERTIFICATION.fields_by_name[
    "acquire_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_CERTIFICATION.fields_by_name[
    "expire_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_SKILL.fields_by_name[
    "last_used_date"
].message_type = google_dot_type_dot_date__pb2._DATE
_SKILL.fields_by_name["level"].enum_type = _SKILLPROFICIENCYLEVEL
_INTERVIEW.fields_by_name["rating"].message_type = _RATING
_INTERVIEW.fields_by_name["outcome"].enum_type = _OUTCOME
_BATCHOPERATIONMETADATA.fields_by_name[
    "state"
].enum_type = _BATCHOPERATIONMETADATA_STATE
_BATCHOPERATIONMETADATA.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHOPERATIONMETADATA.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHOPERATIONMETADATA.fields_by_name[
    "end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHOPERATIONMETADATA_STATE.containing_type = _BATCHOPERATIONMETADATA
DESCRIPTOR.message_types_by_name["TimestampRange"] = _TIMESTAMPRANGE
DESCRIPTOR.message_types_by_name["Location"] = _LOCATION
DESCRIPTOR.message_types_by_name["RequestMetadata"] = _REQUESTMETADATA
DESCRIPTOR.message_types_by_name["ResponseMetadata"] = _RESPONSEMETADATA
DESCRIPTOR.message_types_by_name["DeviceInfo"] = _DEVICEINFO
DESCRIPTOR.message_types_by_name["CustomAttribute"] = _CUSTOMATTRIBUTE
DESCRIPTOR.message_types_by_name["SpellingCorrection"] = _SPELLINGCORRECTION
DESCRIPTOR.message_types_by_name["CompensationInfo"] = _COMPENSATIONINFO
DESCRIPTOR.message_types_by_name["Certification"] = _CERTIFICATION
DESCRIPTOR.message_types_by_name["Skill"] = _SKILL
DESCRIPTOR.message_types_by_name["Interview"] = _INTERVIEW
DESCRIPTOR.message_types_by_name["Rating"] = _RATING
DESCRIPTOR.message_types_by_name["BatchOperationMetadata"] = _BATCHOPERATIONMETADATA
DESCRIPTOR.enum_types_by_name["CompanySize"] = _COMPANYSIZE
DESCRIPTOR.enum_types_by_name["JobBenefit"] = _JOBBENEFIT
DESCRIPTOR.enum_types_by_name["DegreeType"] = _DEGREETYPE
DESCRIPTOR.enum_types_by_name["EmploymentType"] = _EMPLOYMENTTYPE
DESCRIPTOR.enum_types_by_name["JobLevel"] = _JOBLEVEL
DESCRIPTOR.enum_types_by_name["JobCategory"] = _JOBCATEGORY
DESCRIPTOR.enum_types_by_name["PostingRegion"] = _POSTINGREGION
DESCRIPTOR.enum_types_by_name["Visibility"] = _VISIBILITY
DESCRIPTOR.enum_types_by_name["ContactInfoUsage"] = _CONTACTINFOUSAGE
DESCRIPTOR.enum_types_by_name["HtmlSanitization"] = _HTMLSANITIZATION
DESCRIPTOR.enum_types_by_name["CommuteMethod"] = _COMMUTEMETHOD
DESCRIPTOR.enum_types_by_name["SkillProficiencyLevel"] = _SKILLPROFICIENCYLEVEL
DESCRIPTOR.enum_types_by_name["Outcome"] = _OUTCOME
DESCRIPTOR.enum_types_by_name["AvailabilitySignalType"] = _AVAILABILITYSIGNALTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimestampRange = _reflection.GeneratedProtocolMessageType(
    "TimestampRange",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TIMESTAMPRANGE,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Message representing a period of time between two
  timestamps.
  
  
  Attributes:
      start_time:
          Begin of the period (inclusive).
      end_time:
          End of the period (exclusive).
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.TimestampRange)
    ),
)
_sym_db.RegisterMessage(TimestampRange)

Location = _reflection.GeneratedProtocolMessageType(
    "Location",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LOCATION,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""A resource that represents a location with full geographic
  information.
  
  
  Attributes:
      location_type:
          The type of a location, which corresponds to the address lines
          field of
          [google.type.PostalAddress][google.type.PostalAddress]. For
          example, "Downtown, Atlanta, GA, USA" has a type of [LocationT
          ype.NEIGHBORHOOD][google.cloud.talent.v4beta1.Location.Locatio
          nType.NEIGHBORHOOD], and "Kansas City, KS, USA" has a type of 
          [LocationType.LOCALITY][google.cloud.talent.v4beta1.Location.L
          ocationType.LOCALITY].
      postal_address:
          Postal address of the location that includes human readable
          information, such as postal delivery and payments addresses.
          Given a postal address, a postal service can deliver items to
          a premises, P.O. Box, or other delivery location.
      lat_lng:
          An object representing a latitude/longitude pair.
      radius_miles:
          Radius in miles of the job location. This value is derived
          from the location bounding box in which a circle with the
          specified radius centered from
          [google.type.LatLng][google.type.LatLng] covers the area
          associated with the job location. For example, currently,
          "Mountain View, CA, USA" has a radius of 6.17 miles.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Location)
    ),
)
_sym_db.RegisterMessage(Location)

RequestMetadata = _reflection.GeneratedProtocolMessageType(
    "RequestMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_REQUESTMETADATA,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Meta information related to the job searcher or entity
  conducting the job search. This information is used to improve the
  performance of the service.
  
  
  Attributes:
      domain:
          Required if [allow\_missing\_ids][google.cloud.talent.v4beta1.
          RequestMetadata.allow\_missing\_ids] is unset or ``false``.
          The client-defined scope or source of the service call, which
          typically is the domain on which the service has been
          implemented and is currently being run.  For example, if the
          service is being run by client Foo, Inc., on job board
          www.foo.com and career site www.bar.com, then this field is
          set to "foo.com" for use on the job board, and "bar.com" for
          use on the career site.  Note that any improvements to the
          model for a particular tenant site rely on this field being
          set correctly to a unique domain.  The maximum number of
          allowed characters is 255.
      session_id:
          Required if [allow\_missing\_ids][google.cloud.talent.v4beta1.
          RequestMetadata.allow\_missing\_ids] is unset or ``false``.  A
          unique session identification string. A session is defined as
          the duration of an end user's interaction with the service
          over a certain period. Obfuscate this field for privacy
          concerns before providing it to the service.  Note that any
          improvements to the model for a particular tenant site rely on
          this field being set correctly to a unique session ID.  The
          maximum number of allowed characters is 255.
      user_id:
          Required if [allow\_missing\_ids][google.cloud.talent.v4beta1.
          RequestMetadata.allow\_missing\_ids] is unset or ``false``.  A
          unique user identification string, as determined by the
          client. To have the strongest positive impact on search
          quality make sure the client-level is unique. Obfuscate this
          field for privacy concerns before providing it to the service.
          Note that any improvements to the model for a particular
          tenant site rely on this field being set correctly to a unique
          user ID.  The maximum number of allowed characters is 255.
      allow_missing_ids:
          Only set when any of
          [domain][google.cloud.talent.v4beta1.RequestMetadata.domain], 
          [session\_id][google.cloud.talent.v4beta1.RequestMetadata.sess
          ion\_id] and [user\_id][google.cloud.talent.v4beta1.RequestMet
          adata.user\_id] isn't available for some reason. It is highly
          recommended not to set this field and provide accurate
          [domain][google.cloud.talent.v4beta1.RequestMetadata.domain], 
          [session\_id][google.cloud.talent.v4beta1.RequestMetadata.sess
          ion\_id] and [user\_id][google.cloud.talent.v4beta1.RequestMet
          adata.user\_id] for the best service experience.
      device_info:
          The type of device used by the job seeker at the time of the
          call to the service.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.RequestMetadata)
    ),
)
_sym_db.RegisterMessage(RequestMetadata)

ResponseMetadata = _reflection.GeneratedProtocolMessageType(
    "ResponseMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_RESPONSEMETADATA,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Additional information returned to client, such as
  debugging information.
  
  
  Attributes:
      request_id:
          A unique id associated with this call. This id is logged for
          tracking purposes.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ResponseMetadata)
    ),
)
_sym_db.RegisterMessage(ResponseMetadata)

DeviceInfo = _reflection.GeneratedProtocolMessageType(
    "DeviceInfo",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DEVICEINFO,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Device information collected from the job seeker,
  candidate, or other entity conducting the job search. Providing this
  information improves the quality of the search results across devices.
  
  
  Attributes:
      device_type:
          Type of the device.
      id:
          A device-specific ID. The ID must be a unique identifier that
          distinguishes the device from other devices.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.DeviceInfo)
    ),
)
_sym_db.RegisterMessage(DeviceInfo)

CustomAttribute = _reflection.GeneratedProtocolMessageType(
    "CustomAttribute",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CUSTOMATTRIBUTE,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Custom attribute values that are either filterable or
  non-filterable.
  
  
  Attributes:
      string_values:
          Exactly one of [string\_values][google.cloud.talent.v4beta1.Cu
          stomAttribute.string\_values] or [long\_values][google.cloud.t
          alent.v4beta1.CustomAttribute.long\_values] must be specified.
          This field is used to perform a string match
          (``CASE_SENSITIVE_MATCH`` or ``CASE_INSENSITIVE_MATCH``)
          search. For filterable ``string_value``\ s, a maximum total
          number of 200 values is allowed, with each ``string_value``
          has a byte size of no more than 500B. For unfilterable
          ``string_values``, the maximum total byte size of unfilterable
          ``string_values`` is 50KB.  Empty string isn't allowed.
      long_values:
          Exactly one of [string\_values][google.cloud.talent.v4beta1.Cu
          stomAttribute.string\_values] or [long\_values][google.cloud.t
          alent.v4beta1.CustomAttribute.long\_values] must be specified.
          This field is used to perform number range search. (``EQ``,
          ``GT``, ``GE``, ``LE``, ``LT``) over filterable
          ``long_value``.  Currently at most 1 [long\_values][google.clo
          ud.talent.v4beta1.CustomAttribute.long\_values] is supported.
      filterable:
          If the ``filterable`` flag is true, custom field values are
          searchable. If false, values are not searchable.  Default is
          false.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CustomAttribute)
    ),
)
_sym_db.RegisterMessage(CustomAttribute)

SpellingCorrection = _reflection.GeneratedProtocolMessageType(
    "SpellingCorrection",
    (_message.Message,),
    dict(
        DESCRIPTOR=_SPELLINGCORRECTION,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Spell check result.
  
  
  Attributes:
      corrected:
          Indicates if the query was corrected by the spell checker.
      corrected_text:
          Correction output consisting of the corrected keyword string.
      corrected_html:
          Corrected output with html tags to highlight the corrected
          words. Corrected words are called out with the "..." html
          tags.  For example, the user input query is "software
          enginear", where the second word, "enginear," is incorrect. It
          should be "engineer". When spelling correction is enabled,
          this value is "software engineer".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.SpellingCorrection)
    ),
)
_sym_db.RegisterMessage(SpellingCorrection)

CompensationInfo = _reflection.GeneratedProtocolMessageType(
    "CompensationInfo",
    (_message.Message,),
    dict(
        CompensationEntry=_reflection.GeneratedProtocolMessageType(
            "CompensationEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_COMPENSATIONINFO_COMPENSATIONENTRY,
                __module__="google.cloud.talent_v4beta1.proto.common_pb2",
                __doc__="""A compensation entry that represents one component of
    compensation, such as base pay, bonus, or other compensation type.
    
    Annualization: One compensation entry can be annualized if - it contains
    valid
    [amount][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.amount]
    or
    [range][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.range].
    - and its
    [expected\_units\_per\_year][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.expected\_units\_per\_year]
    is set or can be derived. Its annualized range is determined as
    ([amount][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.amount]
    or
    [range][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.range])
    times
    [expected\_units\_per\_year][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.expected\_units\_per\_year].
    
    
    Attributes:
        type:
            Compensation type.  Default is [CompensationType.COMPENSATION\
            _TYPE\_UNSPECIFIED][google.cloud.talent.v4beta1.CompensationIn
            fo.CompensationType.COMPENSATION\_TYPE\_UNSPECIFIED].
        unit:
            Frequency of the specified amount.  Default is [CompensationUn
            it.COMPENSATION\_UNIT\_UNSPECIFIED][google.cloud.talent.v4beta
            1.CompensationInfo.CompensationUnit.COMPENSATION\_UNIT\_UNSPEC
            IFIED].
        compensation_amount:
            Compensation amount. It could be a fixed amount or a floating
            range.
        amount:
            Compensation amount.
        range:
            Compensation range.
        description:
            Compensation description. For example, could indicate equity
            terms or provide additional context to an estimated bonus.
        expected_units_per_year:
            Expected number of units paid each year. If not specified,
            when [Job.employment\_types][google.cloud.talent.v4beta1.Job.e
            mployment\_types] is FULLTIME, a default value is inferred
            based on [unit][google.cloud.talent.v4beta1.CompensationInfo.C
            ompensationEntry.unit]. Default values: - HOURLY: 2080 -
            DAILY: 260 - WEEKLY: 52 - MONTHLY: 12 - ANNUAL: 1
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry)
            ),
        ),
        CompensationRange=_reflection.GeneratedProtocolMessageType(
            "CompensationRange",
            (_message.Message,),
            dict(
                DESCRIPTOR=_COMPENSATIONINFO_COMPENSATIONRANGE,
                __module__="google.cloud.talent_v4beta1.proto.common_pb2",
                __doc__="""Compensation range.
    
    
    Attributes:
        max_compensation:
            The maximum amount of compensation. If left empty, the value
            is set to a maximal compensation value and the currency code
            is set to match the [currency
            code][google.type.Money.currency\_code] of min\_compensation.
        min_compensation:
            The minimum amount of compensation. If left empty, the value
            is set to zero and the currency code is set to match the
            [currency code][google.type.Money.currency\_code] of
            max\_compensation.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CompensationInfo.CompensationRange)
            ),
        ),
        DESCRIPTOR=_COMPENSATIONINFO,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Job compensation details.
  
  
  Attributes:
      entries:
          Job compensation information.  At most one entry can be of
          type [CompensationInfo.CompensationType.BASE][google.cloud.tal
          ent.v4beta1.CompensationInfo.CompensationType.BASE], which is
          referred as **base compensation entry** for the job.
      annualized_base_compensation_range:
          Output only. Annualized base compensation range. Computed as
          base compensation entry's [CompensationEntry.amount][google.cl
          oud.talent.v4beta1.CompensationInfo.CompensationEntry.amount]
          times [CompensationEntry.expected\_units\_per\_year][google.cl
          oud.talent.v4beta1.CompensationInfo.CompensationEntry.expected
          \_units\_per\_year].  See [CompensationEntry][google.cloud.tal
          ent.v4beta1.CompensationInfo.CompensationEntry] for
          explanation on compensation annualization.
      annualized_total_compensation_range:
          Output only. Annualized total compensation range. Computed as
          all compensation entries' [CompensationEntry.amount][google.cl
          oud.talent.v4beta1.CompensationInfo.CompensationEntry.amount]
          times [CompensationEntry.expected\_units\_per\_year][google.cl
          oud.talent.v4beta1.CompensationInfo.CompensationEntry.expected
          \_units\_per\_year].  See [CompensationEntry][google.cloud.tal
          ent.v4beta1.CompensationInfo.CompensationEntry] for
          explanation on compensation annualization.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CompensationInfo)
    ),
)
_sym_db.RegisterMessage(CompensationInfo)
_sym_db.RegisterMessage(CompensationInfo.CompensationEntry)
_sym_db.RegisterMessage(CompensationInfo.CompensationRange)

Certification = _reflection.GeneratedProtocolMessageType(
    "Certification",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CERTIFICATION,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Resource that represents a license or certification.
  
  
  Attributes:
      display_name:
          Name of license or certification.  Number of characters
          allowed is 100.
      acquire_date:
          Acquisition date or effective date of license or
          certification.
      expire_date:
          Expiration date of license of certification.
      authority:
          Authority of license, such as government.  Number of
          characters allowed is 100.
      description:
          Description of license or certification.  Number of characters
          allowed is 100,000.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Certification)
    ),
)
_sym_db.RegisterMessage(Certification)

Skill = _reflection.GeneratedProtocolMessageType(
    "Skill",
    (_message.Message,),
    dict(
        DESCRIPTOR=_SKILL,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Resource that represents a skill of a candidate.
  
  
  Attributes:
      display_name:
          Skill display name.  For example, "Java", "Python".  Number of
          characters allowed is 100.
      last_used_date:
          The last time this skill was used.
      level:
          Skill proficiency level which indicates how proficient the
          candidate is at this skill.
      context:
          A paragraph describes context of this skill.  Number of
          characters allowed is 100,000.
      skill_name_snippet:
          Output only. Skill name snippet shows how the [display\_name][
          google.cloud.talent.v4beta1.Skill.display\_name] is related to
          a search query. It's empty if the [display\_name][google.cloud
          .talent.v4beta1.Skill.display\_name] isn't related to the
          search query.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Skill)
    ),
)
_sym_db.RegisterMessage(Skill)

Interview = _reflection.GeneratedProtocolMessageType(
    "Interview",
    (_message.Message,),
    dict(
        DESCRIPTOR=_INTERVIEW,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Details of an interview.
  
  
  Attributes:
      rating:
          The rating on this interview.
      outcome:
          Required. The overall decision resulting from this interview
          (positive, negative, nuetral).
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Interview)
    ),
)
_sym_db.RegisterMessage(Interview)

Rating = _reflection.GeneratedProtocolMessageType(
    "Rating",
    (_message.Message,),
    dict(
        DESCRIPTOR=_RATING,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""The details of the score received for an assessment or
  interview.
  
  
  Attributes:
      overall:
          Overall score.
      min:
          The minimum value for the score.
      max:
          The maximum value for the score.
      interval:
          The steps within the score (for example, interval = 1 max = 5
          min = 1 indicates that the score can be 1, 2, 3, 4, or 5)
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.Rating)
    ),
)
_sym_db.RegisterMessage(Rating)

BatchOperationMetadata = _reflection.GeneratedProtocolMessageType(
    "BatchOperationMetadata",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BATCHOPERATIONMETADATA,
        __module__="google.cloud.talent_v4beta1.proto.common_pb2",
        __doc__="""Metadata used for long running operations returned by CTS
  batch APIs. It's used to replace
  [google.longrunning.Operation.metadata][google.longrunning.Operation.metadata].
  
  
  Attributes:
      state:
          The state of a long running operation.
      state_description:
          More detailed information about operation state.
      success_count:
          Count of successful item(s) inside an operation.
      failure_count:
          Count of failed item(s) inside an operation.
      total_count:
          Count of total item(s) inside an operation.
      create_time:
          The time when the batch operation is created.
      update_time:
          The time when the batch operation status is updated. The
          metadata and the [update\_time][google.cloud.talent.v4beta1.Ba
          tchOperationMetadata.update\_time] is refreshed every minute
          otherwise cached data is returned.
      end_time:
          The time when the batch operation is finished and [google.long
          running.Operation.done][google.longrunning.Operation.done] is
          set to ``true``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.BatchOperationMetadata)
    ),
)
_sym_db.RegisterMessage(BatchOperationMetadata)


DESCRIPTOR._options = None
_VISIBILITY._options = None
_COMPENSATIONINFO.fields_by_name["annualized_base_compensation_range"]._options = None
_COMPENSATIONINFO.fields_by_name["annualized_total_compensation_range"]._options = None
_SKILL.fields_by_name["skill_name_snippet"]._options = None
_INTERVIEW.fields_by_name["outcome"]._options = None
# @@protoc_insertion_point(module_scope)
