# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from __future__ import absolute_import

from google.cloud.talent_v4beta1 import ApplicationServiceClient
from google.cloud.talent_v4beta1 import CompanyServiceClient
from google.cloud.talent_v4beta1 import CompletionClient
from google.cloud.talent_v4beta1 import EventServiceClient
from google.cloud.talent_v4beta1 import JobServiceClient
from google.cloud.talent_v4beta1 import ProfileServiceClient
from google.cloud.talent_v4beta1 import TenantServiceClient
from google.cloud.talent_v4beta1 import enums
from google.cloud.talent_v4beta1 import types


__all__ = (
    "enums",
    "types",
    "ApplicationServiceClient",
    "CompanyServiceClient",
    "CompletionClient",
    "EventServiceClient",
    "JobServiceClient",
    "ProfileServiceClient",
    "TenantServiceClient",
)
